#[non_exhaustive]pub enum ErrorKind {
InvalidOffset,
InvalidLength,
UnionVectorLengthsMismatched {
tags_len: usize,
values_len: usize,
},
UnknownEnumTag {
source: UnknownEnumTagKind,
},
UnknownUnionTag {
tag: u8,
},
InvalidVtableLength {
length: u16,
},
InvalidUtf8 {
source: Utf8Error,
},
MissingRequired,
MissingNullTerminator,
}Expand description
The possible errors in planus when reading data from a serialized buffer.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
InvalidOffset
The offset was out of bounds.
InvalidLength
The buffer was too short while validating a length field.
UnionVectorLengthsMismatched
A vector of unions had different lengths for the tag and value vectors.
UnknownEnumTag
An enum contained an unknown value. For forward compatibility this error should be handled appropriately.
Fields

source: UnknownEnumTagKindThe enum value that wasn’t recognized.
UnknownUnionTag
An union contained an unknown variant. For forward compatibility this error should be handled appropriately.
InvalidVtableLength
A vtable had an invalid length (too large, too small or unaligned).
InvalidUtf8
A string contained invalid utf-8.
MissingRequired
A required field was missing.
MissingNullTerminator
A string null terminator was missing.
Implementations