Struct Builder

pub struct Builder { /* private fields */ }
Builder for serializing flatbuffers.

Examples

use planus::Builder;
use planus_example::monster_generated::my_game::sample::Weapon;
let mut builder = Builder::new();
let weapon = Weapon::create(&mut builder, "Axe", 24);
builder.finish(weapon, None);

Implementations

Source

impl Builder

pub fn new() -> Self

Creates a new Builder.

pub fn len(&self) -> usize

Gets the length of the internal buffer in bytes.

pub fn is_empty(&self) -> bool

Returns true if the internal buffer is empty.

pub fn with_capacity(capacity: usize) -> Self

Creates a new builder with a specific internal capacity already allocated.

pub fn create_string(&mut self, v: impl WriteAsOffset<str>) -> Offset<str>

Serializes a string and returns the offset to it

pub fn create_vector<T>(&mut self, v: impl WriteAsOffset<[T]>) -> Offset<[T]>

Serializes a slice and returns the offset to it

pub fn create_union_vector<T>( &mut self, v: impl WriteAsUnionVector<T>, ) -> UnionVectorOffset<T>

Serializes a slice of union values and returns the offset to it

pub fn clear(&mut self)

Resets the builders internal state and clears the internal buffer.

pub fn finish<T>( &mut self, root: impl WriteAsOffset<T>, file_identifier: Option<[u8; 4]>, ) -> &[u8]

Finish writing the internal buffer and return a byte slice of it.

This will make sure all alignment requirements are fullfilled and that the file identifier has been written if specified.

Examples
use planus::Builder;
use planus_example::monster_generated::my_game::sample::Weapon;
let mut builder = Builder::new();
let weapon = Weapon::create(&mut builder, "Axe", 24);
builder.finish(weapon, None);

It can also be used to directly serialize an owned flatbuffers struct

use planus::Builder;
use planus_example::monster_generated::my_game::sample::Weapon;
let mut builder = Builder::new();
let weapon = Weapon { name: Some("Sword".to_string()), damage: 12 };
let data = builder.finish(&weapon, None);
pub fn as_slice(&self) -> &[u8]

Returns a reference to the current data buffer.

It will return the same slice as the one return by finish, unless additional data has been appened afterwards.