pub trait VectorRead<'buf>: 'buf { }Expand description
Trait used by generated code to read elements from vectors.
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".
pub trait VectorRead<'buf>: 'buf { }Trait used by generated code to read elements from vectors.
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".